@@ -2,7 +2,8 @@
 # Email: juanma.caaz@gmail.com
 
 import time
-import hwcounter
+import cProfile
+import pstats
 
 def cost(**a):
     '''
@@ -16,31 +17,32 @@ def cost(**a):
     if 'median' not in a:
         a['median'] = False
 
+    if 'extra' not in a:
+        a['extra'] = False
+
     def decorator(function):
         def wrapper(*args, **kwargs):
             loops = a['loops']
             timeCost = 0
-            cpuCicle = 0
 
             for _ in range(loops):
-
-                sc = hwcounter.count()
                 s = time.time()
                 out = function(*args, **kwargs)
                 f = time.time()
-                fc = hwcounter.count()
 
                 timeCost += (f - s) 
-                cpuCicle += (fc - sc)
 
             promedio = ''
             if a['median']:
                 timeCost = timeCost/a['loops']
-                cpuCicle = cpuCicle/a['loops']
                 promedio = ' Promedio activado.'
 
-            print(f'El timepo de ejecucion de {function.__name__} es de: {timeCost} segundos. En {loops} iteraciones.\nHa realizado {cpuCicle} ciclos de CPU.{promedio}')
-
+            print(f'El timepo de ejecucion de {function.__name__} es de: {timeCost} segundos. En {loops} iteraciones.{promedio}')
+            if a['extra']:
+                profile = cProfile.Profile()
+                profile.runcall(function,*args, **kwargs)
+                ps = pstats.Stats(profile)
+                ps.print_stats()
             return out
         return wrapper
     return decorator
